@@ -60,7 +60,7 @@ class UpdateGraph(UpdateGraphBase):
     def after_getting_measurements(self):
         self.graph.update_lines()
         self.graph.update_bars()
-        if self.graph.relative_time > self.graph.window_width:
+        if self.graph.reference_time and (self.graph.relative_time > self.graph.window_width):
             self.graph.wrap()
 
 
