@@ -78,7 +78,7 @@ class NumericalGraph(NumericalGraphBase):
                  colors=None,
                  linestyle='.',
                  data_as_array=False,
-                 time_conversion='datetime'):
+                 time_conversion='numpy'):
         """Initiate figures and axes for data plot as a function of asked types.
 
         Input
@@ -93,25 +93,28 @@ class NumericalGraph(NumericalGraphBase):
         - data_as_array: if sensors return arrays of values for different times
                          instead of values for a single time, put this
                          bool as True (default False)
-        - time_conversion: how to convert from unix time to datetime;
-                           possible values: 'datetime', 'numpy', 'pandas'
-                           ('datetime' and 'pandas' are timezone aware
-                            'numpy is not)
+        - time_conversion: how to convert from unix time to datetime for arrays;
+                           possible values: 'numpy', 'pandas'.
         """
         self.timezone = local_timezone
 
-        time_converters = {'datetime': self._to_datetime_datetime,
-                           'numpy': self._to_datetime_numpy,
-                           'pandas': self._to_datetime_pandas}
-
-        self.time_converter = time_converters[time_conversion]
-
         super().__init__(names=names,
                          data_types=data_types,
                          colors=colors,
                          linestyle=linestyle,
                          data_as_array=data_as_array)
 
+        time_converters = {'datetime': self._to_datetime_datetime,
+                           'numpy': self._to_datetime_numpy,
+                           'pandas': self._to_datetime_pandas}
+
+        self.time_converters = {}
+        for name in self.names:
+            if self.data_as_array[name]:
+                self.time_converters[name] = time_converters[time_conversion]
+            else:
+                self.time_converters[name] = time_converters['datetime']
+
         self.current_data = self.create_empty_data()  # For live updates
 
     def create_axes(self):
@@ -185,18 +188,24 @@ class NumericalGraph(NumericalGraphBase):
         return pd.to_datetime(pd_times, utc=True).dt.tz_convert(self.timezone)
 
     def format_measurement(self, measurement):
-        """Transform measurement from the queue into something usable by plot()
+        """Transform measurement from the queue into something usable by manage_data()
 
-        must return a dict with keys (at least):
-        - 'name' (identifier of sensor)
-        - 'values' (iterable of numerical values read by sensor)
-        - 'time' (time)
+        Can be subclassed to adapt to various applications.
+        Here, assumes data is incoming in the form of a dictionary with at
+        least keys:
+        - 'name' (str, identifier of sensor)
+        - 'time (unix)' (floar or array of floats)
+        - 'values' (iterable of values, or iterable of arrays of values)
 
-        Subclass to adapt to your application.
+        Subclass to adapt to applications.
         """
         data = {key: measurement[key] for key in ('name', 'values')}
+
+        name = measurement['name']
         t_unix = measurement['time (unix)']
-        data['time'] = self.time_converter(t_unix)
+
+        data['time'] = self.time_converters[name](t_unix)
+
         return data
 
     # For static plots -------------------------------------------------------
@@ -241,19 +250,20 @@ class NumericalGraph(NumericalGraphBase):
     def update_lines(self):
         """Update line positions with current data."""
 
-        for lines, current_data in zip(self.lines.values(),
-                                       self.current_data.values()):
+        for name in self.names:
 
-            if not current_data['times']:  # No data yet
-                return
+            lines = self.lines[name]
+            current_data = self.current_data[name]
 
-            times = self.timelist_to_array(current_data['times'])
+            if current_data['times']:  # Avoids problems if no data stored yet
 
-            for line, curr_values in zip(lines,
-                                         current_data['values']):
+                times = self.timelist_to_array[name](current_data['times'])
 
-                values = self.datalist_to_array(curr_values)
-                line.set_data(times, values)
+                for line, curr_values in zip(lines,
+                                             current_data['values']):
+
+                    values = self.datalist_to_array[name](curr_values)
+                    line.set_data(times, values)
 
     def update_time_formatting(self):
         """Use Concise Date Formatting for minimal space used on screen by time"""
